A repository created for the first lab project of UCS633 Data Analytics for Thapar Institute of Engineering and Technology, Patiala, India. Contains a python module that applies the TOPSIS method for choosing the best result out of given options